==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultPreviewPanel.h <==
// class javax.swing.colorchooser.DefaultPreviewPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6bb2b446810c2726 javax_swing_colorchooser_DefaultPreviewPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_
#define _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object	_jc_javax_swing_colorchooser_DefaultPreviewPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24JColorChooser;
	struct _jc_java_lang_String$object	*sample;
	jint	largeGap;
	jint	rightSideRectWidth;
	jint	smallGap;
	jint	squareSize;
	jint	textPadding;
};
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$paintSquare$884f4c0c25f5ebee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$paintSquare$884f4c0c25f5ebee;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *);
	void	(*paintSquare$884f4c0c25f5ebee)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods	javax_swing_colorchooser_DefaultPreviewPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$refs {
    _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs	javax_swing_colorchooser_DefaultPreviewPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs	javax_swing_colorchooser_DefaultPreviewPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object {
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype _jc_javax_swing_colorchooser_DefaultPreviewPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultPreviewPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultPreviewPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultPreviewPanel.h <==
// class javax.swing.colorchooser.DefaultPreviewPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6bb2b446810c2726 javax_swing_colorchooser_DefaultPreviewPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_
#define _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object	_jc_javax_swing_colorchooser_DefaultPreviewPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24JColorChooser;
	struct _jc_java_lang_String$object	*sample;
	jint	largeGap;
	jint	rightSideRectWidth;
	jint	smallGap;
	jint	squareSize;
	jint	textPadding;
};
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel$fields_struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$paintSquare$884f4c0c25f5ebee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel$method_info$paintSquare$884f4c0c25f5ebee;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*paintSquare$884f4c0c25f5ebee)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vmethods	javax_swing_colorchooser_DefaultPreviewPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$refs {
    _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_refs	javax_swing_colorchooser_DefaultPreviewPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultPreviewPanel$sub_nonrefs	javax_swing_colorchooser_DefaultPreviewPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object {
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel$vtype _jc_javax_swing_colorchooser_DefaultPreviewPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultPreviewPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultPreviewPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultPreviewPanel_H_ */
